==> stock_indicators-1.0.0-py3-none-any.whl: stock_indicators/indicators/hma.py <==
from typing import Iterable, Optional, TypeVar

from stock_indicators._cslib import CsIndicator
from stock_indicators._cstypes import List as CsList
from stock_indicators.indicators.common.helpers import RemoveWarmupMixin
from stock_indicators.indicators.common.results import IndicatorResults, ResultBase
from stock_indicators.indicators.common.quote import Quote


def get_hma(quotes: Iterable[Quote], lookback_periods: int):
    """Get HMA calculated.

    Hull Moving Average (HMA) is a modified weighted average
    of Close price over N lookback periods that reduces lag.

    Parameters:
        `quotes` : Iterable[Quote]
            Historical price quotes.

        `lookback_periods` : int
            Number of periods in the lookback window.

    Returns:
        `HMAResults[HMAResult]`
            HMAResults is list of HMAResult with providing useful helper methods.

    See more:
         - [HMA Reference](https://daveskender.github.io/Stock.Indicators.Python/indicators/Hma/#content)
         - [Helper Methods](https://daveskender.github.io/Stock.Indicators.Python/utilities/#content)
    """
    results = CsIndicator.GetHma[Quote](CsList(Quote, quotes), lookback_periods)
    return HMAResults(results, HMAResult)


class HMAResult(ResultBase):
    """
    A wrapper class for a single unit of Hull Moving Average (HMA) results.
    """

    @property
    def hma(self) -> Optional[float]:
        return self._csdata.Hma

    @hma.setter
    def hma(self, value):
        self._csdata.Hma = value


_T = TypeVar("_T", bound=HMAResult)
class HMAResults(RemoveWarmupMixin, IndicatorResults[_T]):
    """
    A wrapper class for the list of Hull Moving Average (HMA) results.
    It is exactly same with built-in `list` except for that it provides
    some useful helper methods written in CSharp implementation.
    """

==> stock_indicators-1.3.5-py3-none-any.whl: stock_indicators/indicators/hma.py <==
from typing import Iterable, Optional, TypeVar

from stock_indicators._cslib import CsIndicator
from stock_indicators._cstypes import List as CsList
from stock_indicators.indicators.common.helpers import CondenseMixin, RemoveWarmupMixin
from stock_indicators.indicators.common.results import IndicatorResults, ResultBase
from stock_indicators.indicators.common.quote import Quote


def get_hma(quotes: Iterable[Quote], lookback_periods: int):
    """Get HMA calculated.

    Hull Moving Average (HMA) is a modified weighted average
    of Close price over N lookback periods that reduces lag.

    Parameters:
        `quotes` : Iterable[Quote]
            Historical price quotes.

        `lookback_periods` : int
            Number of periods in the lookback window.

    Returns:
        `HMAResults[HMAResult]`
            HMAResults is list of HMAResult with providing useful helper methods.

    See more:
         - [HMA Reference](https://python.stockindicators.dev/indicators/Hma/#content)
         - [Helper Methods](https://python.stockindicators.dev/utilities/#content)
    """
    results = CsIndicator.GetHma[Quote](CsList(Quote, quotes), lookback_periods)
    return HMAResults(results, HMAResult)


class HMAResult(ResultBase):
    """
    A wrapper class for a single unit of Hull Moving Average (HMA) results.
    """

    @property
    def hma(self) -> Optional[float]:
        return self._csdata.Hma

    @hma.setter
    def hma(self, value):
        self._csdata.Hma = value


_T = TypeVar("_T", bound=HMAResult)
class HMAResults(CondenseMixin, RemoveWarmupMixin, IndicatorResults[_T]):
    """
    A wrapper class for the list of Hull Moving Average (HMA) results.
    It is exactly same with built-in `list` except for that it provides
    some useful helper methods written in CSharp implementation.
    """
